@@ -11,17 +11,17 @@
    All rights reserved
 
    This file is free software; you can redistribute it and/or modify it
-   under the terms of the Lesser or Library GNU General Public License 
+   under the terms of the Lesser or Library GNU General Public License
    as published by the
    Free Software Foundation; either version 3, or (at your option) any
    later version.
 
    This file is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    Library GNU General Public License for more details.
 
-   You should have received a copy of the Library GNU General Public 
+   You should have received a copy of the Library GNU General Public
    License along with this program; see the file COPYING.  If not, write to
    the Free Software Foundation, 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
@@ -61,6 +61,10 @@ typedef struct
   int lines_before;
   int lines_after;
   int left_margin;
+  int centered_margin;
+  int keep_with_next;
+  int dont_split;
+  int orphan_control;
   int first_line_indent;	/* At true margin if negative */
   sem_act translate;
   int skip_number_lines;	/*Don't write on lines with page numbers */
@@ -77,17 +81,14 @@ typedef struct
 #define vsnprintf _vsnprintf
 #endif
 
-
-#ifndef CHARSIZE
 #define CHARSIZE sizeof (widechar)
-#endif
-
 #define BUFSIZE 8192
 #define MAX_LENGTH BUFSIZE - 4
 #define MAX_TRANS_LENGTH 2 * BUFSIZE - 4
 #define MAXNAMELEN 256
 #define MAXNUMLEN 32
 #define STACKSIZE 100
+#define MAXLINES 512
 
 typedef enum
 {
@@ -106,8 +107,7 @@ typedef enum
 typedef enum
 {
   textDevice = 0,
-  browser,
-  utd
+  browser
 } FormatFor;
 
 typedef enum
@@ -162,9 +162,27 @@ typedef struct
   char *mainBrailleTable;
   char *inbuf;
   int inlen;
-  widechar *outbuf;
-  int outlen;
-  int outlen_so_far;
+  widechar *outbuf1;
+  widechar *outbuf2;
+  widechar *outbuf3;
+  int outbuf1_len;
+  int outbuf2_len;
+  int outbuf3_len;
+  int outbuf1_len_so_far;
+  int outbuf2_len_so_far;
+  int outbuf3_len_so_far;
+  int outbuf2_enabled;
+  int outbuf3_enabled;
+  int fill_pages;
+  int after_contents;
+  int fill_page_skipped;
+  int blank_lines;
+  int print_page_numbers_in_contents;
+  int braille_page_numbers_in_contents;
+  int lines_pagenum[MAXLINES+1];
+  int lines_newpage[MAXLINES+1];
+  int lines_length;
+  BrlPageNumFormat cur_brl_page_num_format;
   int lines_on_page;
   int braille_page_number;
   int prelim_pages;
@@ -191,6 +209,18 @@ typedef struct
   char interline_back_table_name[MAXNAMELEN];
   char semantic_files[MAXNAMELEN];
   widechar print_page_number[MAXNUMLEN];
+  widechar page_separator_number_first[MAXNUMLEN];
+  widechar page_separator_number_last[MAXNUMLEN];
+  widechar print_page_number_first[MAXNUMLEN];
+  widechar print_page_number_last[MAXNUMLEN];
+  int page_separator;
+  int page_separator_number;
+  int ignore_empty_pages;
+  int continue_pages;
+  int merge_unnumbered_pages;
+  int print_page_number_range;
+  int page_number_top_separate_line;
+  int page_number_bottom_separate_line;
   widechar braille_page_string[MAXNUMLEN];
   char lineEnd[8];
   char pageEnd[8];
@@ -270,4 +300,5 @@ int start_style (StyleType * curStyle);
 int end_style (StyleType * curStyle);
 int find_action (const char **actions, const char *action);
 int find_group_length (const char groupSym[2], const char *groupStart);
+
 #endif /*louisxml_h */
