@@ -51,11 +51,23 @@ typedef enum
   heading2,
   heading3,
   heading4,
+  heading5,
+  heading6,
+  heading7,
+  heading8,
+  heading9,
+  heading10,
   contentsheader,
   contents1,
   contents2,
   contents3,
   contents4,
+  contents5,
+  contents6,
+  contents7,
+  contents8,
+  contents9,
+  contents10,
   /* translation */
   notranslate,
   compbrl,
@@ -68,6 +80,7 @@ typedef enum
   boxline,
   italicx,
   boldx,
+  underlinex,
   linespacing,
   blankline,
   softreturn,
