@@ -18,11 +18,23 @@ static const char *semNames[] = {
   "heading2",
   "heading3",
   "heading4",
+  "heading5",
+  "heading6",
+  "heading7",
+  "heading8",
+  "heading9",
+  "heading10",
   "contentsheader",
   "contents1",
   "contents2",
   "contents3",
   "contents4",
+  "contents5",
+  "contents6",
+  "contents7",
+  "contents8",
+  "contents9",
+  "contents10",
   "notranslate",
   "compbrl",
   "uncontracted",
@@ -33,6 +45,7 @@ static const char *semNames[] = {
   "boxline",
   "italicx",
   "boldx",
+  "underlinex",
   "linespacing",
   "blankline",
   "softreturn",
